const fs = require('fs');
const program = require('commander');
const inquirer = require('inquirer');
const files = require('../lib/files');
const questions = require('../lib/questions');
const build = require('../lib/build');
const packages = require(`${process.cwd()}/package.json`);
const FolderSTR = require('../lib/folder');

const clientsFolder = FolderSTR('clients');

const LogoASCII = `
  |-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-|
  |                                                 |
  |    ___ _  _ _____ ___          ___ _    ___     |
  |   |_ _| \\| |_   _|_ _|  ___   / __| |  |_ _|    |
  |    | || .\` | | |  | |  |___| | (__| |__ | |     |
  |   |___|_|\\_| |_| |___|        \\___|____|___|    |
  |                                                 |
  |-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-|                                                   
`;

function startCLI() {
  if (!fs.existsSync(`${process.cwd()}/inti.conf.js`) && !packages.inti) {
    console.log('Você não está na pasta do projeto de FRONT da INTI');
    return false;
  }

  console.log('\x1b[33m', LogoASCII);

  inquirer.prompt([{
      type: 'list',
      name: 'client',
      message: 'What client do you want to build?',
      choices: files.getDirectories(clientsFolder),
      filter: function (val) {
        return val.toLowerCase();
      }
    }])
    .then(({ client }) => {
      questions.askQuestions(client)
    });
}

console.clear();

program
  .version('0.0.1')
  .description(LogoASCII);

program
  .command('start')
  .alias('s')
  .description('Start the CLI questions Interface')
  .action(() => {
    startCLI();
  });

program
  .command('execute')
  .alias('e')
  .option('-f, --folder <clientFolder>')
  .option('-c, --commands <buildCommand>')
  .option('-p, --platform <buildPlatform>')
  .option('-t, --theme [appTheme]')
  .option('-i, --icons')
  .option('-v, --appVersion [appVersion]')
  .option('-d, --deploy')
  .option('-h, --hmg')
  .description('Execute command arguments for build application')
  .action((prog) => {
    const answers = {
      commands: prog.commands || 'development',
      platform: prog.platform || 'web',
      theme: prog.theme || '',
      icons: prog.icons || false,
      appVersion: prog.appVersion || '',
    };

    var deploy = false;
    var client = prog.folder || 'default';
    var hmg = false;

    if (prog.deploy) {
      deploy = true;
      client = 'producao';
      answers.appVersion = 'minor';
    }
    if (prog.hmg) {
      hmg = true;
      answers.appVersion = 'patch';
      client = 'producao';
    }

    build.Application(answers, client)
      .then((args) => {
        build.Compile(args, deploy, hmg);
      })
      .catch(error => console.error(error));
  });

if (!process.argv.slice(2).length) {
  program.outputHelp();
}

program.parse(process.argv);

