const Configs = require('../packages');
const Quasar = require('../quasar');
const Deploy = require('../deploy');
const { updateEnviroment } = require('../packages');

class Compiler {
  constructor(parameters) {
    this.commands = [];
    this.mode = parameters.commands;
    this.theme = parameters.theme;
    this.platform = parameters.platform;

    this.start();
  }

  start() {
    if (this.mode === 'development') this.startDevelopment();
    if (this.mode === 'build') this.startBuild();
    this.selectPlatform();
    this.defineTheme();
  }

  startDevelopment() {
    this.commands.push('dev');
    Configs.updateEnviroment('LOCAL');
  }

  startBuild() {
    this.commands.push('build');
  }

  selectPlatform() {
    if (this.platform === 'mobile') {
      this.defineCordova();
      this.defineTargetMobile();
    }
  }

  defineCordova() {
    this.commands.push('--mode');
    this.commands.push('cordova');
    Configs.updateEnviroment('CORDOVA');
  }

  defineTargetMobile() {
    if (this.theme === 'android') {
      this.commands.push('-T');
      this.commands.push('android');
    }
    if (this.theme === 'ios') {
      this.commands.push('-T');
      this.commands.push('ios');
    }
  }

  defineTheme() {
    if (this.theme === 'android') {
      this.commands.push('--theme');
      this.commands.push('mat');
    }
    if (this.theme === 'ios') {
      this.commands.push('--theme');
      this.commands.push('ios');
    }
  }

  prepareForDeploy(hmg) {
    return Quasar.clean()
      .then(() => {
        hmg ? updateEnviroment('HMGMAT') : updateEnviroment('MAT');
      })
      .then(() => {
        return Quasar.buildMaterial()
      });
  }

  compile(isWeb, deploy, hmg) {
    if (!isWeb) {
      return Quasar.clean()
        .then(() => Quasar.build(this.commands));
    }
    return this.prepareForDeploy(hmg)
      .then(() => {
        Deploy.compressBundle()
      })
      .then(() => {
        if (hmg) return Deploy.sendTest();
        if (deploy) return Deploy.send();
      });
  }
}

module.exports = Compiler;
