const fs = require('fs-extra');
const xml2json = require('xml2json');
const jsonfile = require('jsonfile');
const iconsSplashConfig = require('../icons/config');
const FolderSTR = require('../folder');

const configXML = FolderSTR('cordova') + '/config.xml';
const clientsDir = FolderSTR('clients');
const quasarDir = FolderSTR('quasar');
const packagesCordova = FolderSTR('cordova') + '/package.json';

class Cordova {
  constructor(client) {
    console.log('\x1b[31m', 'Criando definições para aplicativo mobile');
    this.client = client;
  }

  makeIconsForPlatform(platform) {
    let tmpIcons = [];
    if (platform === 'android') {
      iconsSplashConfig.androidIcons.forEach((icons) => {
        tmpIcons.push({
          platform,
          density: icons.density,
          src: `res/icons/android/${icons.name}`,
        });
      });
    }
    if (platform === 'ios') {
      iconsSplashConfig.iosIcons.forEach((icons) => {
        tmpIcons.push({
          platform,
          src: `res/icons/ios/${icons.name}`,
          height: icons.size,
          width: icons.size,
        });
      });
    }
    return tmpIcons;
  }

  makeSplashScreensForPlatform(platform) {
    let tmpSplash = [];
    if (platform === 'android') {
      iconsSplashConfig.androidSplash.forEach((splash) => {
        tmpSplash.push({
          platform,
          density: splash.density,
          src: `res/screens/android/${splash.name}`,
        });
      });
    }
    if (platform === 'ios') {
      iconsSplashConfig.iosSplash.forEach((splash) => {
        tmpSplash.push({
          platform,
          src: `res/screens/ios/${splash.name}`,
          height: splash.height,
          width: splash.width,
        });
      });
    }

    return tmpSplash;
  }

  configXml() {
    console.log('\x1b[31m', 'Atualizando definições do config.xml do Cordova');

    const config = require(`${clientsDir}/${this.client}/config/config.json`);
    const baseXML = fs.readFileSync(configXML, 'utf-8');

    const configJson = xml2json.toJson(baseXML, {
      object: true,
      reversible: true,
      coerce: true,
      arrayNotation: false,
    });

    configJson.widget.id = config.cordova.id;
    configJson.widget.version = config.cordova.version;
    configJson.widget.name.$t = config.name;
    configJson.widget.description.$t = config.cordova.description;

    let tmpPlatform = [];

    configJson.widget.platform.forEach((platform) => {
      platform.icon = this.makeIconsForPlatform(platform.name);
      platform.splash = this.makeSplashScreensForPlatform(platform.name);
      tmpPlatform.push(platform);
    });

    configJson.widget.platform = tmpPlatform;

    let tmpPreferences = [];

    configJson.widget.preference.forEach((preference) => {
      if (preference.name === 'StatusBarBackgroundColor') {
        preference.value = config.color;
      }
      tmpPreferences.push(preference);
    });

    configJson.widget.preference = tmpPreferences;

    configJson.widget.platform = tmpPlatform;

    const updatedXml = xml2json.toXml(configJson);

    fs.writeFileSync(configXML, updatedXml);
  }

  updatePackagesJson() {
    console.log('\x1b[31m', 'Atualizando definições do package.json do Cordova');

    const config = require(`${clientsDir}/${this.client}/config/config.json`);

    const updatedJson = jsonfile.readFileSync(packagesCordova);

    updatedJson.name = config.cordova.id;
    updatedJson.version = config.cordova.version;
    updatedJson.displayName = config.name;
    updatedJson.description = config.cordova.description;

    jsonfile.writeFileSync(packagesCordova, updatedJson, { spaces: 2 });

    fs.removeSync(`${packagesCordova}.lock`);
  }

  static clearPlatform() {
    try {
      fs.removeSync(`${quasarDir}/src-cordova/platforms`);
    }
    catch (err) {
      console.error(err);
    }
  }
}

module.exports = Cordova;