const path = require('path');
const FolderSTR = require('../folder');
const splashiconGenerator = require('../splashicon-generator');
const iconConfigs = require('./config');

const clientsDir = FolderSTR('clients');

function generate(client) {
  const clientFolder = path.join(clientsDir, client);

  const cordova = path.join(clientFolder, 'src-cordova', 'res');
  const favicon = path.join(clientFolder, 'src', 'statics', 'icons');

  const options = {
    ICON_FILE: `${clientFolder}/src-cordova/icon.png`,
    SPLASH_FILE: `${clientFolder}/src-cordova/splash.png`,
    ICON_PLATFORMS: [
      {
        name: 'android',
        iconsPath: path.join(cordova, 'icons', 'android'),
        isAdded: true,
        icons: iconConfigs.androidIcons,
      },
      {
        name: 'ios',
        isAdded: true,
        iconsPath: path.join(cordova, 'icons', 'ios'),
        icons: iconConfigs.iosIcons,
      },
      {
        name: 'store',
        iconsPath: clientFolder,
        isAdded: true,
        icons: iconConfigs.storeIcons,
      },
      {
        name: 'web',
        iconsPath: favicon,
        isAdded: true,
        icons: iconConfigs.webIcons,
      }],
    SPLASH_PLATFORMS: [
      {
        name: 'ios',
        isAdded: true,
        splashPath: path.join(cordova, 'screens', 'ios'),
        splash: iconConfigs.iosSplash,
      },
      {
        name: 'android',
        isAdded: true,
        splashPath: path.join(cordova, 'screens', 'android'),
        splash: iconConfigs.androidSplash,
      }],
  };

  return new Promise((resolve, reject) => {
    splashiconGenerator.generate(options)
      .then((result) => {
        resolve(result);
      })
      .catch((error) => {
        reject(error);
      });
  });
}

module.exports = generate;
