const versionManager = require('../version');
const jsonFile = require('jsonfile');
const folder = require('../folder');
const clientsDir = folder('clients');
const packagesSrc = folder('quasar') + '/package.json';
const environmentSrc = folder('quasar') + '/environment.json';

class Configs {
  constructor(parameters) {
    this.client = parameters.client;
    this.version = parameters.version;
  }

  updatePackagesJson() {
    console.log('\x1b[31m', 'Atualizando definições do package.json do Quasar');
    const configJson = jsonFile.readFileSync(`${clientsDir}/${this.client}/config/config.json`);

    let updatedJson = jsonFile.readFileSync(packagesSrc);

    updatedJson.productName = configJson.name;
    updatedJson.version = configJson.cordova.version;
    updatedJson.cordovaId = configJson.cordova.id;
    updatedJson.description = configJson.cordova.description;

    jsonFile.writeFileSync(packagesSrc, updatedJson, { spaces: 2 });
    //fs.removeSync(`${packagesSrc}.lock`);
  }

  updateConfig() {
    const configJson = `${clientsDir}/${this.client}/config/config.json`;

    let updatedJson = jsonFile.readFileSync(configJson);

    let appVersion = versionManager.updateVersion(this.version, updatedJson.cordova.version);

    updatedJson.cordova.version = appVersion;

    jsonFile.writeFileSync(configJson, updatedJson, { spaces: 2 });
    console.log('\x1b[31m', `Atualizando Versão do aplicativo para -> [${appVersion}]`);
    return true;
  }

  static updateEnviroment(enviroment) {
    console.log('\x1b[31m', `Atualizando Ambiente do aplicativo para -> [${enviroment}]`);

    const updatedJson = jsonFile.readFileSync(environmentSrc);
    updatedJson.env = enviroment;
    jsonFile.writeFileSync(environmentSrc, updatedJson, { spaces: 2 });
    return true;
  }
}

module.exports = Configs;